@@ -1,7 +1,7 @@
 package Dist::Zilla::PluginBundle::Author::PERLANCAR;
 
-our $DATE = '2016-06-30'; # DATE
-our $VERSION = '0.51'; # VERSION
+our $DATE = '2016-07-13'; # DATE
+our $VERSION = '0.52'; # VERSION
 
 use Moose;
 with 'Dist::Zilla::Role::PluginBundle::Easy';
@@ -13,7 +13,7 @@ sub configure {
 
     $self->add_bundle(Filter => {
         -bundle => '@Classic',
-        -remove => [qw/PkgVersion PodVersion Readme/],
+        -remove => [qw/PkgVersion PodVersion Readme UploadToCPAN/],
     });
 
     $self->add_plugins(
@@ -41,6 +41,7 @@ sub configure {
         'SetScriptShebang',
         'Test::Compile',
         'Test::Rinci',
+        'UploadToCPAN::WWWPAUSESimple',
         'EnsureSQLSchemaVersionedTest',
         ['Acme::CPANLists::Blacklist' => {module_list=>[q[PERLANCAR::Avoided::Modules I'm currently avoiding]]}],
         'Prereqs::EnsureVersion',
@@ -64,7 +65,7 @@ Dist::Zilla::PluginBundle::Author::PERLANCAR - Dist::Zilla like PERLANCAR when y
 
 =head1 VERSION
 
-This document describes version 0.51 of Dist::Zilla::PluginBundle::Author::PERLANCAR (from Perl distribution Dist-Zilla-PluginBundle-Author-PERLANCAR), released on 2016-06-30.
+This document describes version 0.52 of Dist::Zilla::PluginBundle::Author::PERLANCAR (from Perl distribution Dist-Zilla-PluginBundle-Author-PERLANCAR), released on 2016-07-13.
 
 =head1 SYNOPSIS
 
