@@ -1,7 +1,7 @@
 package Dist::Zilla::PluginBundle::Author::PERLANCAR::NonCPAN;
 
-our $DATE = '2016-06-30'; # DATE
-our $VERSION = '0.51'; # VERSION
+our $DATE = '2016-07-13'; # DATE
+our $VERSION = '0.52'; # VERSION
 
 use Moose;
 with 'Dist::Zilla::Role::PluginBundle::Easy';
@@ -13,7 +13,7 @@ sub configure {
 
     $self->add_bundle(Filter => {
         -bundle => '@Author::PERLANCAR',
-        -remove => [qw/Authority ConfirmRelease UploadToCPAN/],
+        -remove => [qw/Authority ConfirmRelease UploadToCPAN::WWWPAUSESimple/],
     });
 }
 
@@ -34,7 +34,7 @@ Dist::Zilla::PluginBundle::Author::PERLANCAR::NonCPAN - Dist::Zilla like PERLANC
 
 =head1 VERSION
 
-This document describes version 0.51 of Dist::Zilla::PluginBundle::Author::PERLANCAR::NonCPAN (from Perl distribution Dist-Zilla-PluginBundle-Author-PERLANCAR), released on 2016-06-30.
+This document describes version 0.52 of Dist::Zilla::PluginBundle::Author::PERLANCAR::NonCPAN (from Perl distribution Dist-Zilla-PluginBundle-Author-PERLANCAR), released on 2016-07-13.
 
 =head1 SYNOPSIS
 
